@@ -23,6 +23,8 @@ import os
 import subprocess
 import sys
 
+from dbnd_airflow.utils import create_dbnd_pool
+
 
 # DO NOT IMPORT ANYTHING FROM AIRFLOW
 # we need to initialize some config values first
@@ -116,6 +118,11 @@ def main(args=None):
 
     args.func(args)
 
+    if func_name in ["resetdb", "initdb"]:
+        pool_name = dbnd_config.get("airflow", "dbnd_pool")
+        if pool_name == "dbnd_pool":
+            create_dbnd_pool(pool_name)
+
 
 if __name__ == "__main__":
     main()
